// Copyright (c) 2019 Dominic Masters
//
// MIT License
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import { App } from '@yourwishes/app-base';
import { ServerModule } from '@yourwishes/app-server';
import { ReactModule } from '@yourwishes/app-react';
import { ISimpleReactApp, SimpleReactModule } from '@yourwishes/app-simple-react';
import { IEmailApp, EmailModule } from '@yourwishes/app-email';
import { domsPlaceModule } from './../module/';

import { domsPlaceCompiler } from './../compiler/';

export class domsPlaceApp extends App implements ISimpleReactApp, IEmailApp {
  server:ServerModule;
  email:EmailModule;
  react:ReactModule;
  simpleReact:SimpleReactModule;
  domsPlace:domsPlaceModule;

  constructor() {
    super();

    this.server = new ServerModule(this);
    this.email = new EmailModule(this);
    this.react = new ReactModule(this);
    this.simpleReact = new SimpleReactModule(this);
    this.domsPlace = new domsPlaceModule(this);

    [
      this.server, this.email, this.react, this.simpleReact, this.domsPlace
    ].forEach(e => this.modules.addModule(e));
  }

  getCompiler() {
    return new domsPlaceCompiler();
  }
}
